@@ -2,9 +2,8 @@
 # from lazyearth.mainfile import objearth
 # from lazyearth.mainfile import water
 
-from lazyearth.mainfile import objearth
-from lazyearth.mainfile import water
+from lazyearth.objearth import objearth
+from lazyearth.water import water
 
-from lazyearth.test_mainfile import employee
-__version__ = '0.0.56'
+__version__ = '0.0.57'
 print(f'Lazyearth version : {__version__}')
\ No newline at end of file
